@@ -859,8 +859,8 @@ feed_getitems(struct item **items, size_t *nitems, ssize_t want,
 
 	*items = NULL;
 	*nitems = 0;
-	if (fseek(fp, offset, SEEK_SET))
-		goto err;
+//	if (fseek(fp, offset, SEEK_SET))
+//		goto err;
 
 	/* if loading all items, set cap to 0, expand later */
 	if (want == -1) {
@@ -880,8 +880,10 @@ feed_getitems(struct item **items, size_t *nitems, ssize_t want,
 			if (line[linelen - 1] == '\n')
 				line[--linelen] = '\0';
 
-			if (linetoitem(line, item) == -1)
+			if (linetoitem(line, item) == -1) {
+				i--;
 				continue;
+			}
 
 			(*nitems)++;
 		}
@@ -949,7 +951,6 @@ feed_load(struct feed *f, FILE *fp)
 	struct row *row;
 	ssize_t want;
 	size_t i;
-	int ret;
 
 	for (i = 0; i < nitems; i++) {
 		free(items[i].title);
@@ -970,8 +971,7 @@ feed_load(struct feed *f, FILE *fp)
 
 	want = -1; /* all */
 
-	ret = feed_getitems(&items, &nitems, want, fp, 0);
-	if (ret == -1)
+	if (feed_getitems(&items, &nitems, want, fp, 0) == -1)
 		err(1, "%s: %s", __func__, f->path);
 
 	f->totalnew = 0;
@@ -1039,6 +1039,9 @@ loadfiles(int argc, char *argv[])
 	FILE *fp;
 	size_t i;
 	char *name;
+	int istty;
+
+	istty = isatty(ttyfd);
 
 	feeds = ecalloc(argc, sizeof(struct feed));
 
@@ -1047,24 +1050,12 @@ loadfiles(int argc, char *argv[])
 	/* 1 day is old news */
 	comparetime -= 86400;
 
-	if ((devnullfd = open("/dev/null", O_WRONLY)) < 0)
-		err(1, "open: /dev/null");
-
 	totalnew = totalcount = 0;
 	if (argc == 1) {
 		feeds[0].name = "stdin";
-
 		if (!(fp = fdopen(ttyfd, "rb")))
 			err(1, "fdopen");
 		feed_load(&feeds[0], fp);
-
-		/* close and re-attach to stdin */
-		close(0); // TODO: fclose ?
-		if ((ttyfd = open("/dev/tty", O_RDONLY)) == -1)
-			err(1, "open: /dev/tty");
-		if (dup2(ttyfd, 0) == -1)
-			err(1, "dup2: /dev/tty");
-
 		nfeeds = 1;
 		totalnew += feeds[0].totalnew;
 		totalcount += feeds[0].total;
@@ -1088,6 +1079,14 @@ loadfiles(int argc, char *argv[])
 		/* load first items, because of first selection. */
 		feed_loadfile(&feeds[0], feeds[0].path);
 	}
+
+	if (!istty) {
+		close(ttyfd);
+		if ((ttyfd = open("/dev/tty", O_RDONLY)) == -1)
+			err(1, "open: /dev/tty");
+		if (dup2(ttyfd, 0) == -1)
+			err(1, "dup2: /dev/tty");
+	}
 }
 
 void
@@ -1116,8 +1115,6 @@ updatesidebar(int onlynew)
 
 	feedw = 0;
 	for (i = 0; i < nfeeds; i++) {
-		if (onlynew && feeds[i].totalnew == 0)
-			continue;
 		snprintf(bufw, sizeof(bufw), "%s (%ld/%ld)",
 		               feeds[i].name,  feeds[i].totalnew, feeds[i].total);
 		len = colw(bufw);
@@ -1303,6 +1300,9 @@ main(int argc, char *argv[])
 		selpane = PaneItems;
 	}
 
+	if ((devnullfd = open("/dev/null", O_WRONLY)) < 0)
+		err(1, "open: /dev/null");
+
 	updatetitle();
 	updatesidebar(onlynew);
 	init();
@@ -1434,7 +1434,6 @@ nextpage:
 						break;
 					}
 				}
-
 			}
 			break;
 		case 12: /* ^L */
@@ -1469,7 +1468,6 @@ nextpage:
 			fflush(stdout);
 			break;
 		case 's': /* toggle sidebar */
-			// TODO: mark as dirty.
 			panes[PaneFeeds].hidden = !panes[PaneFeeds].hidden;
 			if (selpane == PaneFeeds && panes[PaneFeeds].hidden)
 				selpane = PaneItems;
